#line 2 "libharp/harp-operation-scanner.c"

#line 4 "libharp/harp-operation-scanner.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer harp_operation_parser__create_buffer
#define yy_delete_buffer harp_operation_parser__delete_buffer
#define yy_scan_buffer harp_operation_parser__scan_buffer
#define yy_scan_string harp_operation_parser__scan_string
#define yy_scan_bytes harp_operation_parser__scan_bytes
#define yy_init_buffer harp_operation_parser__init_buffer
#define yy_flush_buffer harp_operation_parser__flush_buffer
#define yy_load_buffer_state harp_operation_parser__load_buffer_state
#define yy_switch_to_buffer harp_operation_parser__switch_to_buffer
#define yypush_buffer_state harp_operation_parser_push_buffer_state
#define yypop_buffer_state harp_operation_parser_pop_buffer_state
#define yyensure_buffer_stack harp_operation_parser_ensure_buffer_stack
#define yy_flex_debug harp_operation_parser__flex_debug
#define yyin harp_operation_parser_in
#define yyleng harp_operation_parser_leng
#define yylex harp_operation_parser_lex
#define yylineno harp_operation_parser_lineno
#define yyout harp_operation_parser_out
#define yyrestart harp_operation_parser_restart
#define yytext harp_operation_parser_text
#define yywrap harp_operation_parser_wrap
#define yyalloc harp_operation_parser_alloc
#define yyrealloc harp_operation_parser_realloc
#define yyfree harp_operation_parser_free

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define harp_operation_parser__create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer harp_operation_parser__create_buffer
#endif

#ifdef yy_delete_buffer
#define harp_operation_parser__delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer harp_operation_parser__delete_buffer
#endif

#ifdef yy_scan_buffer
#define harp_operation_parser__scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer harp_operation_parser__scan_buffer
#endif

#ifdef yy_scan_string
#define harp_operation_parser__scan_string_ALREADY_DEFINED
#else
#define yy_scan_string harp_operation_parser__scan_string
#endif

#ifdef yy_scan_bytes
#define harp_operation_parser__scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes harp_operation_parser__scan_bytes
#endif

#ifdef yy_init_buffer
#define harp_operation_parser__init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer harp_operation_parser__init_buffer
#endif

#ifdef yy_flush_buffer
#define harp_operation_parser__flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer harp_operation_parser__flush_buffer
#endif

#ifdef yy_load_buffer_state
#define harp_operation_parser__load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state harp_operation_parser__load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define harp_operation_parser__switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer harp_operation_parser__switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define harp_operation_parser_push_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state harp_operation_parser_push_buffer_state
#endif

#ifdef yypop_buffer_state
#define harp_operation_parser_pop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state harp_operation_parser_pop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define harp_operation_parser_ensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack harp_operation_parser_ensure_buffer_stack
#endif

#ifdef yylex
#define harp_operation_parser_lex_ALREADY_DEFINED
#else
#define yylex harp_operation_parser_lex
#endif

#ifdef yyrestart
#define harp_operation_parser_restart_ALREADY_DEFINED
#else
#define yyrestart harp_operation_parser_restart
#endif

#ifdef yylex_init
#define harp_operation_parser_lex_init_ALREADY_DEFINED
#else
#define yylex_init harp_operation_parser_lex_init
#endif

#ifdef yylex_init_extra
#define harp_operation_parser_lex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra harp_operation_parser_lex_init_extra
#endif

#ifdef yylex_destroy
#define harp_operation_parser_lex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy harp_operation_parser_lex_destroy
#endif

#ifdef yyget_debug
#define harp_operation_parser_get_debug_ALREADY_DEFINED
#else
#define yyget_debug harp_operation_parser_get_debug
#endif

#ifdef yyset_debug
#define harp_operation_parser_set_debug_ALREADY_DEFINED
#else
#define yyset_debug harp_operation_parser_set_debug
#endif

#ifdef yyget_extra
#define harp_operation_parser_get_extra_ALREADY_DEFINED
#else
#define yyget_extra harp_operation_parser_get_extra
#endif

#ifdef yyset_extra
#define harp_operation_parser_set_extra_ALREADY_DEFINED
#else
#define yyset_extra harp_operation_parser_set_extra
#endif

#ifdef yyget_in
#define harp_operation_parser_get_in_ALREADY_DEFINED
#else
#define yyget_in harp_operation_parser_get_in
#endif

#ifdef yyset_in
#define harp_operation_parser_set_in_ALREADY_DEFINED
#else
#define yyset_in harp_operation_parser_set_in
#endif

#ifdef yyget_out
#define harp_operation_parser_get_out_ALREADY_DEFINED
#else
#define yyget_out harp_operation_parser_get_out
#endif

#ifdef yyset_out
#define harp_operation_parser_set_out_ALREADY_DEFINED
#else
#define yyset_out harp_operation_parser_set_out
#endif

#ifdef yyget_leng
#define harp_operation_parser_get_leng_ALREADY_DEFINED
#else
#define yyget_leng harp_operation_parser_get_leng
#endif

#ifdef yyget_text
#define harp_operation_parser_get_text_ALREADY_DEFINED
#else
#define yyget_text harp_operation_parser_get_text
#endif

#ifdef yyget_lineno
#define harp_operation_parser_get_lineno_ALREADY_DEFINED
#else
#define yyget_lineno harp_operation_parser_get_lineno
#endif

#ifdef yyset_lineno
#define harp_operation_parser_set_lineno_ALREADY_DEFINED
#else
#define yyset_lineno harp_operation_parser_set_lineno
#endif

#ifdef yywrap
#define harp_operation_parser_wrap_ALREADY_DEFINED
#else
#define yywrap harp_operation_parser_wrap
#endif

#ifdef yyalloc
#define harp_operation_parser_alloc_ALREADY_DEFINED
#else
#define yyalloc harp_operation_parser_alloc
#endif

#ifdef yyrealloc
#define harp_operation_parser_realloc_ALREADY_DEFINED
#else
#define yyrealloc harp_operation_parser_realloc
#endif

#ifdef yyfree
#define harp_operation_parser_free_ALREADY_DEFINED
#else
#define yyfree harp_operation_parser_free
#endif

#ifdef yytext
#define harp_operation_parser_text_ALREADY_DEFINED
#else
#define yytext harp_operation_parser_text
#endif

#ifdef yyleng
#define harp_operation_parser_leng_ALREADY_DEFINED
#else
#define yyleng harp_operation_parser_leng
#endif

#ifdef yyin
#define harp_operation_parser_in_ALREADY_DEFINED
#else
#define yyin harp_operation_parser_in
#endif

#ifdef yyout
#define harp_operation_parser_out_ALREADY_DEFINED
#else
#define yyout harp_operation_parser_out
#endif

#ifdef yy_flex_debug
#define harp_operation_parser__flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug harp_operation_parser__flex_debug
#endif

#ifdef yylineno
#define harp_operation_parser_lineno_ALREADY_DEFINED
#else
#define yylineno harp_operation_parser_lineno
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

#define harp_operation_parser_wrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 60
#define YY_END_OF_BUFFER 61
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[297] =
    {   0,
        0,    0,   61,   59,   58,   58,   59,   59,   55,   59,
       56,   59,   59,   59,   54,   59,   13,   14,   54,   54,
       54,   54,   54,   54,   54,   54,   54,   54,   54,   54,
       54,   54,   58,    8,    4,    0,    1,    0,   55,   57,
       57,   56,    0,    6,    7,    3,    5,   54,    0,    2,
       54,   54,   54,   54,   54,   54,   54,   54,   12,   54,
       54,   54,   54,   54,   54,   54,   54,   54,   54,   54,
       54,   54,   54,   54,   54,   54,    0,   57,    0,   57,
       54,   19,   54,   54,   54,   54,   54,   54,   54,   54,
       10,   54,   54,   54,   54,    9,   11,   54,   54,   54,

       54,   36,   54,   54,   54,   54,   54,   54,   54,   54,
       54,    0,   57,   54,   54,   54,   54,   54,   54,   54,
       54,   54,   54,   54,   54,   42,   29,   54,   54,   54,
       54,   54,   54,   54,   38,   54,   54,   54,   48,   54,
       54,   41,   54,   54,   21,   54,   54,   54,   54,   54,
       45,   54,   28,   43,   44,   54,   54,   54,   33,   54,
       54,   54,   54,   54,   54,   40,   54,   54,   54,   54,
       54,   24,   46,   54,   54,   54,   54,   54,   54,   34,
       35,   37,   54,   39,   47,   54,   54,   54,   54,   54,
       54,   26,   27,   54,   54,   54,   54,   54,   54,   54,

       54,   54,   54,   54,   54,   54,   54,   49,   54,   54,
       54,   52,   51,   54,   54,   54,   54,   54,   54,   54,
       50,   54,   54,   54,   54,   54,   54,   54,   54,   54,
       54,   54,   54,   54,   54,   54,   20,   54,   54,   54,
       53,   54,   54,   54,   54,   54,   54,   54,   54,   54,
       54,   54,   54,   54,   54,   54,   54,   54,   54,   54,
       54,   54,   32,   54,   54,   54,   54,   22,   54,   54,
       54,   31,   54,   54,   54,   54,   23,   54,   30,   15,
       54,   17,   54,   54,   16,   54,   54,   54,   54,   54,
       54,   18,   54,   54,   25,    0

    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        2,    2,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    5,    1,    1,    1,    6,    1,    1,
        1,    7,    8,    1,    8,    9,    1,   10,   11,   12,
       13,   10,   10,   14,   10,   15,   10,    1,    1,   16,
       17,   18,    7,    1,   19,   19,   19,   19,   20,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       21,   22,   23,    1,   24,    1,   25,   26,   27,   28,

       29,   30,   31,   32,   33,   19,   34,   35,   36,   37,
       38,   39,   40,   41,   42,   43,   44,   45,   46,   47,
       19,   19,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[48] =
    {   0,
        1,    1,    1,    1,    1,    1,    2,    1,    3,    4,
        4,    4,    4,    4,    4,    1,    1,    1,    2,    4,
        5,    1,    1,    2,    2,    2,    2,    2,    4,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2
    } ;

static const flex_int16_t yy_base[304] =
    {   0,
        0,    0,  637,  638,   46,   48,   46,   48,    0,   44,
       51,  619,   55,  618,  627,  610,   55,   57,   59,   60,
       58,   66,   62,   71,   68,   70,   69,   74,   75,   76,
       95,   78,   84,  638,  638,   69,  638,  629,    0,   59,
       92,  107,  118,  638,  638,  638,  638,  624,  607,  606,
      110,   85,  116,  103,  118,  127,  128,  135,  133,  136,
      137,  130,  138,  139,  141,  146,  142,  140,  143,  150,
      144,  145,  151,  155,  157,  174,  181,  177,  190,  197,
      206,  208,  207,  209,  212,  210,  211,  213,  214,  218,
      621,  215,  216,  217,  220,  620,  619,  222,  227,  226,

      228,  618,  230,  231,  234,  233,  242,  235,  245,  241,
      247,  277,  283,  255,  258,  262,  264,  259,  250,  263,
      256,  265,  266,  269,  270,  617,  616,  273,  296,  274,
      299,  302,  303,  304,  615,  305,  307,  308,  614,  312,
      311,  613,  319,  314,  612,  315,  321,  325,  313,  326,
      606,  327,  601,  593,  592,  316,  318,  344,  590,  330,
      336,  331,  323,  350,  352,  589,  359,  324,  360,  362,
      363,  365,  588,  364,  366,  367,  368,  369,  372,  586,
      585,  584,  370,  583,  582,  373,  371,  377,  374,  378,
      383,  581,  578,  384,  385,  387,  394,  392,  395,  399,

      402,  400,  403,  404,  411,  415,  416,  576,  417,  401,
      428,  575,  574,  419,  421,  429,  431,  434,  435,  432,
      437,  440,  441,  443,  446,  447,  452,  455,  448,  450,
      456,  457,  458,  460,  464,  465,  572,  469,  467,  461,
      570,  470,  471,  472,  484,  485,  495,  473,  474,  499,
      500,  505,  504,  506,  507,  508,  509,  510,  511,  512,
      513,  517,  568,  519,  518,  521,  514,  567,  520,  526,
      528,  320,  533,  523,  548,  535,  317,  554,  163,  162,
      527,  161,  555,  557,  159,  531,  529,  558,  559,  561,
      532,  149,  562,  564,  147,  638,  601,  605,  607,  610,

      614,   80,   64
    } ;

static const flex_int16_t yy_def[304] =
    {   0,
      296,    1,  296,  296,  296,  296,  296,  297,  298,  296,
      299,  296,  296,  296,  300,  301,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  296,  296,  296,  297,  296,  297,  298,  302,
      303,  299,  296,  296,  296,  296,  296,  300,  301,  301,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  296,  303,  296,  296,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,

      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  296,  296,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,

      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,  300,  300,  300,  300,  300,
      300,  300,  300,  300,  300,    0,  296,  296,  296,  296,

      296,  296,  296
    } ;

static const flex_int16_t yy_nxt[686] =
    {   0,
        4,    5,    6,    7,    8,    4,    9,    4,   10,   11,
       11,   11,   11,   11,   11,   12,   13,   14,   15,   15,
       16,    4,    4,    4,   17,   18,   19,   20,   21,   22,
       15,   15,   23,   24,   25,   15,   26,   15,   27,   15,
       28,   29,   30,   15,   31,   32,   15,   33,   33,   33,
       33,   34,   37,   40,   40,   40,   40,   40,   40,   41,
       45,   39,   35,   39,   39,   39,   39,   78,   39,   38,
       43,   46,   39,   37,   39,   39,   39,   39,   77,   43,
       39,   39,   39,   40,   39,   33,   33,   77,   55,   52,
       38,   39,   61,   53,   63,   51,   54,   56,   59,   60,

       58,   39,   66,   67,   57,   62,   65,   64,   73,   39,
       68,   77,   69,   70,   71,   41,   39,   72,   76,   74,
       77,   82,   39,   75,   39,   79,   43,   80,   80,   80,
       80,   80,   80,   39,   39,   43,   39,   84,   81,   39,
       83,   39,   39,   39,   39,   39,   39,   39,   39,   39,
       39,   39,   39,   39,   87,   39,   39,   39,   85,   88,
       90,   39,   91,   39,   93,   39,   95,   39,   39,   39,
       86,   99,   89,   98,   96,   92,  100,  103,  105,   94,
       39,   97,  101,  104,  102,  107,  108,  106,  112,  109,
      113,  113,  113,  113,  113,  113,   77,  110,  111,   80,

       80,   80,   80,   80,   80,   77,   80,   80,   80,   80,
       80,   80,   39,   39,   39,   39,   39,   39,   39,   39,
       39,   39,   39,   39,   39,  124,   39,  125,   39,  126,
      114,  115,   39,   39,   39,  119,   39,   39,  122,   39,
       39,   39,  116,  117,  118,  120,  123,   39,   39,  128,
      129,   39,  133,   39,  127,  121,   39,  137,  130,  131,
      136,   39,   39,  139,   39,   39,  132,  134,   39,   39,
       39,   39,   39,  135,  138,   39,   39,  140,  143,   39,
       39,  155,  154,  141,  148,  142,  113,  113,  113,  113,
      113,  113,  113,  113,  113,  113,  113,  113,  150,  144,

      145,  146,   39,  147,  152,   39,  149,  151,   39,   39,
       39,   39,  153,   39,   39,  156,  158,   39,   39,   39,
       39,   39,   39,   39,   39,   39,   39,   39,  157,   39,
       39,   39,   39,   39,  160,  159,   39,   39,  161,  166,
      174,  171,   39,  167,  165,  168,  162,  163,  164,  172,
       39,  169,  170,  173,  175,  176,   39,  180,   39,  177,
      178,  187,  182,  183,  181,   39,   39,  179,   39,   39,
       39,   39,   39,   39,   39,   39,   39,   39,   39,   39,
       39,  184,  185,   39,   39,  186,  189,  190,  191,   39,
       39,   39,  192,   39,  199,  195,  188,  200,   39,  197,

       39,   39,  193,  194,  198,   39,   39,   39,   39,   39,
       39,  207,  196,  208,  209,  201,  204,   39,  202,  203,
      205,   39,   39,   39,  206,   39,  210,   39,  211,  212,
      214,  216,  215,  213,   39,   39,  217,   39,   39,  218,
       39,   39,  222,   39,  220,  221,   39,   39,  225,   39,
      219,  223,   39,   39,   39,  227,   39,  228,   39,  224,
      231,   39,   39,   39,   39,  233,   39,   39,  230,  226,
       39,   39,  229,   39,  235,   39,   39,   39,   39,   39,
       39,  243,  232,  245,  234,  240,  237,  246,  236,  238,
       39,   39,  241,  247,  251,  239,  242,  248,  244,  249,

      253,   39,  258,  250,  259,   39,   39,  252,  254,  256,
       39,   39,   39,   39,   39,   39,   39,   39,   39,   39,
       39,  257,  255,   39,   39,   39,   39,   39,  263,   39,
      260,  262,   39,   39,   39,   39,  261,   39,   39,   39,
      270,   39,  269,  271,  265,  272,  264,  273,  266,  275,
      274,  267,  268,  278,   39,  276,  279,  280,  283,  281,
       39,   39,  277,   39,   39,   39,  289,   39,   39,  285,
       39,  288,  282,   39,   39,  293,   39,  284,   39,  286,
       39,   39,   39,  287,   39,  292,  290,   39,   39,   39,
       39,   39,   39,  291,   39,   39,   39,  294,   39,   39,

      295,   36,   36,   36,   36,   36,   39,   39,   39,   42,
       42,   48,   39,   48,   49,   49,   49,   49,   39,   39,
       39,   39,   39,   39,   39,   39,   39,   39,   50,   50,
       39,  296,   50,   39,   47,   44,  296,    3,  296,  296,
      296,  296,  296,  296,  296,  296,  296,  296,  296,  296,
      296,  296,  296,  296,  296,  296,  296,  296,  296,  296,
      296,  296,  296,  296,  296,  296,  296,  296,  296,  296,
      296,  296,  296,  296,  296,  296,  296,  296,  296,  296,
      296,  296,  296,  296,  296
    } ;

static const flex_int16_t yy_chk[686] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    5,    5,    6,
        6,    7,    8,   10,   10,   10,   10,   10,   10,   11,
       13,   17,    7,   18,   21,   19,   20,  303,   23,    8,
       11,   13,   22,   36,   25,   27,   26,   24,   40,   11,
       28,   29,   30,  302,   32,   33,   33,   40,   20,   18,
       36,   52,   25,   19,   26,   17,   19,   20,   23,   24,

       22,   31,   28,   29,   21,   25,   27,   26,   30,   54,
       29,   41,   29,   29,   29,   42,   51,   29,   32,   31,
       41,   52,   53,   31,   55,   43,   42,   43,   43,   43,
       43,   43,   43,   56,   57,   42,   62,   54,   51,   59,
       53,   58,   60,   61,   63,   64,   68,   65,   67,   69,
       71,   72,   66,  295,   57,  292,   70,   73,   55,   58,
       59,   74,   59,   75,   60,  285,   62,  282,  280,  279,
       56,   66,   58,   65,   63,   59,   66,   68,   70,   61,
       76,   64,   66,   69,   67,   72,   73,   71,   77,   74,
       77,   77,   77,   77,   77,   77,   78,   75,   76,   79,

       79,   79,   79,   79,   79,   78,   80,   80,   80,   80,
       80,   80,   81,   83,   82,   84,   86,   87,   85,   88,
       89,   92,   93,   94,   90,   92,   95,   92,   98,   92,
       81,   82,  100,   99,  101,   86,  103,  104,   89,  106,
      105,  108,   83,   84,   85,   87,   90,  110,  107,   94,
       95,  109,  101,  111,   93,   88,  119,  106,   98,   99,
      105,  114,  121,  108,  115,  118,  100,  103,  116,  120,
      117,  122,  123,  104,  107,  124,  125,  109,  114,  128,
      130,  125,  124,  110,  119,  111,  112,  112,  112,  112,
      112,  112,  113,  113,  113,  113,  113,  113,  121,  115,

      116,  117,  129,  118,  123,  131,  120,  122,  132,  133,
      134,  136,  123,  137,  138,  128,  130,  141,  140,  149,
      144,  146,  156,  277,  157,  143,  272,  147,  129,  163,
      168,  148,  150,  152,  132,  131,  160,  162,  133,  140,
      149,  146,  161,  141,  138,  143,  134,  136,  137,  147,
      158,  143,  144,  148,  150,  152,  164,  160,  165,  156,
      157,  168,  162,  163,  161,  167,  169,  158,  170,  171,
      174,  172,  175,  176,  177,  178,  183,  187,  179,  186,
      189,  164,  165,  188,  190,  167,  170,  171,  172,  191,
      194,  195,  174,  196,  183,  177,  169,  186,  198,  179,

      197,  199,  175,  176,  179,  200,  202,  210,  201,  203,
      204,  194,  178,  195,  196,  187,  189,  205,  188,  188,
      190,  206,  207,  209,  191,  214,  197,  215,  198,  199,
      201,  203,  202,  200,  211,  216,  204,  217,  220,  205,
      218,  219,  210,  221,  207,  209,  222,  223,  215,  224,
      206,  211,  225,  226,  229,  217,  230,  218,  227,  214,
      221,  228,  231,  232,  233,  223,  234,  240,  220,  216,
      235,  236,  219,  239,  225,  238,  242,  243,  244,  248,
      249,  232,  222,  234,  224,  229,  227,  235,  226,  228,
      245,  246,  230,  236,  242,  228,  231,  238,  233,  239,

      244,  247,  248,  240,  249,  250,  251,  243,  245,  246,
      253,  252,  254,  255,  256,  257,  258,  259,  260,  261,
      267,  247,  245,  262,  265,  264,  269,  266,  253,  274,
      250,  252,  270,  281,  271,  287,  251,  286,  291,  273,
      260,  276,  259,  261,  255,  262,  254,  264,  256,  266,
      265,  257,  258,  270,  275,  267,  271,  273,  276,  274,
      278,  283,  269,  284,  288,  289,  287,  290,  293,  281,
      294,  286,  275,  268,  263,  291,  241,  278,  237,  283,
      213,  212,  208,  284,  193,  290,  288,  192,  185,  184,
      182,  181,  180,  289,  173,  166,  159,  293,  155,  154,

      294,  297,  297,  297,  297,  297,  298,  153,  298,  299,
      299,  300,  151,  300,  301,  301,  301,  301,  145,  142,
      139,  135,  127,  126,  102,   97,   96,   91,   50,   49,
       48,   38,   16,   15,   14,   12,    3,  296,  296,  296,
      296,  296,  296,  296,  296,  296,  296,  296,  296,  296,
      296,  296,  296,  296,  296,  296,  296,  296,  296,  296,
      296,  296,  296,  296,  296,  296,  296,  296,  296,  296,
      296,  296,  296,  296,  296,  296,  296,  296,  296,  296,
      296,  296,  296,  296,  296
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "../harp/libharp/harp-operation-scanner.l"
/*
 * Copyright (C) 2015-2022 S[&]T, The Netherlands.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its
 *    contributors may be used to endorse or promote products derived from
 *    this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
/* *INDENT-OFF* */
#define YY_NO_INPUT 1
#line 41 "../harp/libharp/harp-operation-scanner.l"
#include <stdlib.h>
#include <string.h>

#include "harp-operation.h"
#include "harp-program.h"

typedef struct harp_sized_array_struct harp_sized_array;

#include "harp-operation-parser.h"

#line 995 "libharp/harp-operation-scanner.c"
#line 996 "libharp/harp-operation-scanner.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 62 "../harp/libharp/harp-operation-scanner.l"


#line 1214 "libharp/harp-operation-scanner.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 297 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 638 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 64 "../harp/libharp/harp-operation-scanner.l"
{
                            yylval.string_val = (char *)malloc(yyleng - 1);
                            memcpy(yylval.string_val, yytext + 1, yyleng - 2);
                            yylval.string_val[yyleng - 2] = '\0';
                            return STRING_VALUE;
                        }
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 70 "../harp/libharp/harp-operation-scanner.l"
{
                            yylval.string_val = (char *)malloc(yyleng - 1);
                            memcpy(yylval.string_val, yytext + 1, yyleng - 2);
                            yylval.string_val[yyleng - 2] = '\0';
                            return UNIT;
                        }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 77 "../harp/libharp/harp-operation-scanner.l"
return EQUAL;
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 78 "../harp/libharp/harp-operation-scanner.l"
return NOT_EQUAL;
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 79 "../harp/libharp/harp-operation-scanner.l"
return GREATER_EQUAL;
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 80 "../harp/libharp/harp-operation-scanner.l"
return LESS_EQUAL;
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 81 "../harp/libharp/harp-operation-scanner.l"
return BIT_AND;
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 82 "../harp/libharp/harp-operation-scanner.l"
return BIT_NAND;
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 84 "../harp/libharp/harp-operation-scanner.l"
return NAN;
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 85 "../harp/libharp/harp-operation-scanner.l"
return INF;
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 86 "../harp/libharp/harp-operation-scanner.l"
return NOT;
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 87 "../harp/libharp/harp-operation-scanner.l"
return IN;
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 89 "../harp/libharp/harp-operation-scanner.l"
return ID_A;
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 90 "../harp/libharp/harp-operation-scanner.l"
return ID_B;
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 92 "../harp/libharp/harp-operation-scanner.l"
return FUNC_AREA_COVERS_AREA;
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 93 "../harp/libharp/harp-operation-scanner.l"
return FUNC_AREA_COVERS_POINT;
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 94 "../harp/libharp/harp-operation-scanner.l"
return FUNC_AREA_INSIDE_AREA;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 95 "../harp/libharp/harp-operation-scanner.l"
return FUNC_AREA_INTERSECTS_AREA;
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 96 "../harp/libharp/harp-operation-scanner.l"
return FUNC_BIN;
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 97 "../harp/libharp/harp-operation-scanner.l"
return FUNC_BIN_SPATIAL;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 98 "../harp/libharp/harp-operation-scanner.l"
return FUNC_CLAMP;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 99 "../harp/libharp/harp-operation-scanner.l"
return FUNC_COLLOCATE_LEFT;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 100 "../harp/libharp/harp-operation-scanner.l"
return FUNC_COLLOCATE_RIGHT;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 101 "../harp/libharp/harp-operation-scanner.l"
return FUNC_DERIVE;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 102 "../harp/libharp/harp-operation-scanner.l"
return FUNC_DERIVE_SMOOTHED_COLUMN;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 103 "../harp/libharp/harp-operation-scanner.l"
return FUNC_EXCLUDE;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 104 "../harp/libharp/harp-operation-scanner.l"
return FUNC_FLATTEN;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 105 "../harp/libharp/harp-operation-scanner.l"
return FUNC_INDEX;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 106 "../harp/libharp/harp-operation-scanner.l"
return FUNC_KEEP;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 107 "../harp/libharp/harp-operation-scanner.l"
return FUNC_LONGITUDE_RANGE;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 108 "../harp/libharp/harp-operation-scanner.l"
return FUNC_POINT_DISTANCE;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 109 "../harp/libharp/harp-operation-scanner.l"
return FUNC_POINT_IN_AREA;
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 110 "../harp/libharp/harp-operation-scanner.l"
return FUNC_REBIN;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 111 "../harp/libharp/harp-operation-scanner.l"
return FUNC_REGRID;
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 112 "../harp/libharp/harp-operation-scanner.l"
return FUNC_RENAME;
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 113 "../harp/libharp/harp-operation-scanner.l"
return FUNC_SET;
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 114 "../harp/libharp/harp-operation-scanner.l"
return FUNC_SMOOTH;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 115 "../harp/libharp/harp-operation-scanner.l"
return FUNC_SORT;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 116 "../harp/libharp/harp-operation-scanner.l"
return FUNC_SQUASH;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 117 "../harp/libharp/harp-operation-scanner.l"
return FUNC_VALID;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 118 "../harp/libharp/harp-operation-scanner.l"
return FUNC_WRAP;
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 120 "../harp/libharp/harp-operation-scanner.l"
{
                            yylval.int32_val = harp_type_int8;
                            return DATATYPE;
                        }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 124 "../harp/libharp/harp-operation-scanner.l"
{
                            yylval.int32_val = harp_type_int16;
                            return DATATYPE;
                        }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 128 "../harp/libharp/harp-operation-scanner.l"
{
                            yylval.int32_val = harp_type_int32;
                            return DATATYPE;
                        }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 132 "../harp/libharp/harp-operation-scanner.l"
{
                            yylval.int32_val = harp_type_float;
                            return DATATYPE;
                        }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 136 "../harp/libharp/harp-operation-scanner.l"
{
                            yylval.int32_val = harp_type_double;
                            return DATATYPE;
                        }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 140 "../harp/libharp/harp-operation-scanner.l"
{
                            yylval.int32_val = harp_type_string;
                            return DATATYPE;
                        }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 145 "../harp/libharp/harp-operation-scanner.l"
{
                            yylval.int32_val = harp_dimension_time;
                            return DIMENSION;
                        }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 149 "../harp/libharp/harp-operation-scanner.l"
{
                            yylval.int32_val = harp_dimension_latitude;
                            return DIMENSION;
                        }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 153 "../harp/libharp/harp-operation-scanner.l"
{
                            yylval.int32_val = harp_dimension_longitude;
                            return DIMENSION;
                        }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 157 "../harp/libharp/harp-operation-scanner.l"
{
                            yylval.int32_val = harp_dimension_vertical;
                            return DIMENSION;
                        }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 161 "../harp/libharp/harp-operation-scanner.l"
{
                            yylval.int32_val = harp_dimension_spectral;
                            return DIMENSION;
                        }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 165 "../harp/libharp/harp-operation-scanner.l"
{
                            yylval.int32_val = harp_dimension_independent;
                            return DIMENSION;
                        }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 170 "../harp/libharp/harp-operation-scanner.l"
{
                            yylval.string_val = strdup(yytext);
                            return NAME;
                        }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 174 "../harp/libharp/harp-operation-scanner.l"
{
                            yylval.string_val = strdup(yytext);
                            return NAME_PATTERN;
                        }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 178 "../harp/libharp/harp-operation-scanner.l"
{
                            yylval.string_val = strdup(yytext);
                            return INTEGER_VALUE;
                        }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 182 "../harp/libharp/harp-operation-scanner.l"
{
                            yylval.string_val = strdup(yytext);
                            return DOUBLE_VALUE;
                        }
	YY_BREAK
case 58:
/* rule 58 can match eol */
YY_RULE_SETUP
#line 186 "../harp/libharp/harp-operation-scanner.l"
/* eat whitespace */
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 187 "../harp/libharp/harp-operation-scanner.l"
return (*yytext);
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 188 "../harp/libharp/harp-operation-scanner.l"
ECHO;
	YY_BREAK
#line 1632 "libharp/harp-operation-scanner.c"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 297 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 297 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 296);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

	b->yy_is_interactive = 1;

	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 188 "../harp/libharp/harp-operation-scanner.l"
